Index: /modules/branches/2.5/fw_fop/module.xml
===================================================================
--- /modules/branches/2.5/fw_fop/module.xml (revision 6493)
+++ /modules/branches/2.5/fw_fop/module.xml (revision 6493)
@@ -0,0 +1,17 @@
+
+ fw_fop
+ FreePBX FOP Framework
+ 2.5.0
+ no
+ no
+
+ *2.5.0* First release of fw_fop
+
+
+ This module provides a facility to install bug fixes to the FOP code that is not otherwise housed in a module, it used to be part of framework but has been removed to isolate FOP from Framework updates.
+
+ setup
+ Basic
+ release/2.5/fw_fop-2.5.0.tgz
+ eed5fae9611aaf976464452bca027723
+
Index: /modules/branches/2.5/fw_fop/install.php
===================================================================
--- /modules/branches/2.5/fw_fop/install.php (revision 6493)
+++ /modules/branches/2.5/fw_fop/install.php (revision 6493)
@@ -0,0 +1,86 @@
+'cp -rf' from src: '$src' to dst: '$dst'...details follow
";
+ foreach ($errors as $error) {
+ echo "$error
";
+ }
+}
+
+if (! function_exists('out')) {
+ function out($text) {
+ echo $text."
";
+ }
+}
+
+if (! function_exists('outn')) {
+ function outn($text) {
+ echo $text;
+ }
+}
+
+if (! function_exists('error')) {
+ function error($text) {
+ echo "[ERROR] ".$text."
";
+ }
+}
+
+if (! function_exists('fatal')) {
+ function fatal($text) {
+ echo "[FATAL] ".$text."
";
+ exit(1);
+ }
+}
+
+if (! function_exists('debug')) {
+ function debug($text) {
+ global $debug;
+
+ if ($debug) echo "[DEBUG-preDB] ".$text."
";
+ }
+}
+
+global $amp_conf;
+global $asterisk_conf;
+
+$debug = false;
+$dryrun = false;
+
+/** verison_compare that works with freePBX version numbers
+ * included here because there are some older versions of functions.inc.php that do not have
+ * it included as it was added during 2.3.0beta1
+ */
+if (!function_exists('version_compare_freepbx')) {
+ function version_compare_freepbx($version1, $version2, $op = null) {
+ $version1 = str_replace("rc","RC", strtolower($version1));
+ $version2 = str_replace("rc","RC", strtolower($version2));
+ if (!is_null($op)) {
+ return version_compare($version1, $version2, $op);
+ } else {
+ return version_compare($version1, $version2);
+ }
+ }
+}
+
+/*
+ * fw_fop install script
+ */
+
+ $htdocs_panel_source = dirname(__FILE__)."/htdocs_panel/*";
+
+ // There was a past bug where FOPWEBROOT was pointing to AMPWEBROOT so if that is the case then hardcode
+ // and force to panel here.
+ //
+ $htdocs_panel_dest = $amp_conf['FOPWEBROOT'];
+ if ($htdocs_panel_dest == $amp_conf['AMPWEBROOT']) {
+ $htdocs_panel_dest .= "/panel";
+ }
+
+ exec("cp -rf $htdocs_panel_source $htdocs_panel_dest 2>&1",$out,$ret);
+ if ($ret != 0) {
+ fw_fop_print_errors($htdocs_panel_source, $htdocs_panel_dest, $out);
+ }
+
+?>
Index: /modules/branches/2.5/framework/module.xml
===================================================================
--- /modules/branches/2.5/framework/module.xml (revision 6475)
+++ /modules/branches/2.5/framework/module.xml (revision 6493)
@@ -2,8 +2,9 @@
framework
FreePBX Framework
- 2.5.0rc2.1
+ 2.5.0rc2.2
no
no
+ *2.5.0rc2.2* #3107, #3093, #3090, #3113, $3117
*2.5.0rc2.1* #3104 fix some urlencoding/decoding re: #3102 changes
*2.5.0rc2.0* #3067, #3086, #3082, #3102
Index: /modules/branches/2.5/framework/install.php
===================================================================
--- /modules/branches/2.5/framework/install.php (revision 5590)
+++ /modules/branches/2.5/framework/install.php (revision 6493)
@@ -74,5 +74,4 @@
$bin_source = dirname(__FILE__)."/bin/*";
$agibin_source = dirname(__FILE__)."/agi-bin/*";
- $htdocs_panel_source = dirname(__FILE__)."/htdocs_panel/*";
// These are required by libfreepbx.install.php library for upgrade routines
@@ -84,12 +83,4 @@
$bin_dest = isset($amp_conf['AMPBIN']) ? $amp_conf['AMPBIN'] : '/var/lib/asterisk/bin';
$agibin_dest = isset($asterisk_conf['astagidir']) ? $asterisk_conf['astagidir']:'/var/lib/asterisk/agi-bin';
-
- // There was a past bug where FOPWEBROOT was pointing to AMPWEBROOT so if that is the case then hardcode
- // and force to panel here.
- //
- $htdocs_panel_dest = $amp_conf['FOPWEBROOT'];
- if ($htdocs_panel_dest == $amp_conf['AMPWEBROOT']) {
- $htdocs_panel_dest .= "/panel";
- }
exec("cp -rf $htdocs_source $htdocs_dest 2>&1",$out,$ret);
@@ -108,9 +99,4 @@
}
- exec("cp -rf $htdocs_panel_source $htdocs_panel_dest 2>&1",$out,$ret);
- if ($ret != 0) {
- framework_print_errors($htdocs_panel_source, $htdocs_panel_dest, $out);
- }
-
if (function_exists('upgrade_all')) {
upgrade_all(getversion());
Index: /modules/branches/2.5/frameworksvn.pl
===================================================================
--- /modules/branches/2.5/frameworksvn.pl (revision 5909)
+++ /modules/branches/2.5/frameworksvn.pl (revision 6493)
@@ -30,4 +30,4 @@
system("tar -zxOf ".$filename." ".$moddir."/svnversion.txt");
print "Geting svn log since that version for $rver : .... \n\n";
- $svnver = system("svn log http://svn.freepbx.org/freepbx/trunk -r `tar -zxOf ".$filename." ".$moddir."/svnversion.txt | sed -e s/SVN\\\ VERSION://`:HEAD");
+ $svnver = system("svn log http://svn.freepbx.org/freepbx/branches/$rver -r `tar -zxOf ".$filename." ".$moddir."/svnversion.txt | sed -e s/SVN\\\ VERSION://`:HEAD");
Index: /modules/branches/2.5/fw_ari/module.xml
===================================================================
--- /modules/branches/2.5/fw_ari/module.xml (revision 6493)
+++ /modules/branches/2.5/fw_ari/module.xml (revision 6493)
@@ -0,0 +1,17 @@
+
+ fw_ari
+ FreePBX ARI Framework
+ 2.5.0
+ no
+ no
+
+ *2.5.0* #3104 and First release of fw_ari
+
+
+ This module provides a facility to install bug fixes to the ARI code that is not otherwise housed in a module, it used to be part of framework but has been removed to isolate ARI from Framework updates.
+
+ setup
+ Basic
+ release/2.5/fw_ari-2.5.0.tgz
+ 33ba4ab8c67cdb3d6c98f834aca62401
+
Index: /modules/branches/2.5/fw_ari/install.php
===================================================================
--- /modules/branches/2.5/fw_ari/install.php (revision 6493)
+++ /modules/branches/2.5/fw_ari/install.php (revision 6493)
@@ -0,0 +1,81 @@
+'cp -rf' from src: '$src' to dst: '$dst'...details follow
";
+ foreach ($errors as $error) {
+ echo "$error
";
+ }
+}
+
+if (! function_exists('out')) {
+ function out($text) {
+ echo $text."
";
+ }
+}
+
+if (! function_exists('outn')) {
+ function outn($text) {
+ echo $text;
+ }
+}
+
+if (! function_exists('error')) {
+ function error($text) {
+ echo "[ERROR] ".$text."
";
+ }
+}
+
+if (! function_exists('fatal')) {
+ function fatal($text) {
+ echo "[FATAL] ".$text."
";
+ exit(1);
+ }
+}
+
+if (! function_exists('debug')) {
+ function debug($text) {
+ global $debug;
+
+ if ($debug) echo "[DEBUG-preDB] ".$text."
";
+ }
+}
+
+include dirname(__FILE__)."/libfreepbx.install.php";
+
+global $amp_conf;
+global $asterisk_conf;
+
+$debug = false;
+$dryrun = false;
+
+/** verison_compare that works with freePBX version numbers
+ * included here because there are some older versions of functions.inc.php that do not have
+ * it included as it was added during 2.3.0beta1
+ */
+if (!function_exists('version_compare_freepbx')) {
+ function version_compare_freepbx($version1, $version2, $op = null) {
+ $version1 = str_replace("rc","RC", strtolower($version1));
+ $version2 = str_replace("rc","RC", strtolower($version2));
+ if (!is_null($op)) {
+ return version_compare($version1, $version2, $op);
+ } else {
+ return version_compare($version1, $version2);
+ }
+ }
+}
+
+/*
+ * fw_ari install script
+ */
+
+ $htdocs_ari_source = dirname(__FILE__)."/htdocs_ari/*";
+ $htdocs_ari_dest = $amp_conf['AMPWEBROOT']."/recordings";
+
+ exec("cp -rf $htdocs_ari_source $htdocs_ari_dest 2>&1",$out,$ret);
+ if ($ret != 0) {
+ fw_ari_print_errors($htdocs_panel_source, $htdocs_panel_dest, $out);
+ }
+
+?>
Index: /modules/branches/2.5/publish.pl
===================================================================
--- /modules/branches/2.5/publish.pl (revision 6399)
+++ /modules/branches/2.5/publish.pl (revision 6493)
@@ -10,4 +10,6 @@
$fwbranch = "branches/2.5";
$framework = "framework";
+$fw_fop = "fw_fop";
+$fw_ari = "fw_ari";
my $reldir = "release/";
@@ -35,7 +37,4 @@
die "FATAL: failed to export htdocs directory\n";
}
- if (system("svn export http://svn.freepbx.org/freepbx/$fwbranch/amp_conf/htdocs_panel $framework/htdocs_panel")) {
- die "FATAL: failed to export htdocs_panel directory\n";
- }
if (system("svn export http://svn.freepbx.org/freepbx/$fwbranch/upgrades $framework/upgrades")) {
die "FATAL: failed to export upgrades directory\n";
@@ -65,8 +64,8 @@
}
# Now we must remove a few files which users may have legitimately edited. For now this is the main.conf.php file which is the current
# ARI file used for editing paramters and options.
#
- if (system("rm -rf $framework/htdocs/recordings/includes/main.conf.php")) {
+ if (system("rm -rf $framework/htdocs/recordings")) {
die "FATAL: failed to trim main.conf.php ARI file\n";
}
@@ -86,4 +85,41 @@
die "FATAL: failed to trim modules/_cache\n";
}
+ }
+ if ($moddir =~ /$fw_fop/) {
+
+ if (system("svn export http://svn.freepbx.org/freepbx/$fwbranch/amp_conf/htdocs_panel $fw_fop/htdocs_panel")) {
+ die "FATAL: failed to export htdocs_panel directory\n";
+ }
+
+ # Create the svnversion information for this framework snapshot
+ #
+ if (system("echo SVN VERSION: `svn log -q -r HEAD http://svn.freepbx.org/ | cut -s -f 1 -d ' ' | cut -b '2-'` > $fw_fop/svnversion.txt")) {
+ die "FATAL: svnversion failed to create svnversion.txt\n";
+ }
+
+ }
+ if ($moddir =~ /$fw_ari/) {
+
+ if (system("rm -rf $fw_ari/htdocs_ari")) {
+ die "FATAL: failed to remove previoulsly exported directories\n";
+ }
+
+ # Create the svnversion information for this framework snapshot
+ #
+ if (system("echo SVN VERSION: `svn log -q -r HEAD http://svn.freepbx.org/ | cut -s -f 1 -d ' ' | cut -b '2-'` > $fw_fop/svnversion.txt")) {
+ die "FATAL: svnversion failed to create svnversion.txt\n";
+ }
+
+ if (system("svn export http://svn.freepbx.org/freepbx/$fwbranch/amp_conf/htdocs/recordings $fw_ari/htdocs_ari")) {
+ die "FATAL: failed to export htdocs directory\n";
+ }
+
+ # Now we must remove a few files which users may have legitimately edited. For now this is the main.conf.php file which is the current
+ # ARI file used for editing paramters and options.
+ #
+ if (system("rm -rf $fw_ari/htdocs_ari/includes/main.conf.php")) {
+ die "FATAL: failed to trim main.conf.php ARI file\n";
+ }
+
}
@@ -117,4 +153,14 @@
$files .= "$x ";
}
+ } elsif ($moddir =~ /$fw_fop/) {
+ next if ($x =~ /module.xml/);
+ next if ($x =~ /htdocs_panel/);
+ next if ($x =~ /svnversion.txt/);
+ $files .= "$x ";
+ } elsif ($moddir =~ /$fw_ari/) {
+ next if ($x =~ /module.xml/);
+ next if ($x =~ /htdocs_ari/);
+ next if ($x =~ /svnversion.txt/);
+ $files .= "$x ";
} else {
while ($x = shift @arr) {
@@ -164,3 +210,2 @@
}
}
-
@@ -65,8 +64,8 @@
}
- # Now we must remove a few files which users may have legitimately edited. For now this is the main.conf.php file which is the current
+ # Now we must remove a few files which users may have legitimately edited. For now, all of ARI moved to new module
# ARI file used for editing paramters and options.
#